package de.jottyfan.timetrack.moduls.done;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;

import org.junit.jupiter.api.Test;

import de.jottyfan.timetrack.modules.done.DoneBean;

/**
 * 
 * @author henkej
 *
 */
public class TestDoneBean {

	@Test
	public void testGetLocalDateTimeFromHHmm() {
		LocalDateTime ldt = LocalDateTime.now();
		ldt = ldt.withSecond(0).withNano(0);
		assertEquals(ldt.withHour(0).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("0:0", LocalDateTime.now()));
		assertEquals(ldt.withHour(0).withMinute(5), new DoneBean().getLocalDateTimeFromHHmm("0:5", LocalDateTime.now()));
		assertEquals(ldt.withHour(3).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("3:2", LocalDateTime.now()));
		assertEquals(ldt.withHour(3).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("03:2", LocalDateTime.now()));
		assertEquals(ldt.withHour(10).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("10:2", LocalDateTime.now()));
		assertEquals(ldt.withHour(12).withMinute(2), new DoneBean().getLocalDateTimeFromHHmm("12:02", LocalDateTime.now()));
		assertEquals(ldt.withHour(12).withMinute(20), new DoneBean().getLocalDateTimeFromHHmm("12:20", LocalDateTime.now()));
		assertEquals(null, new DoneBean().getLocalDateTimeFromHHmm(null, LocalDateTime.now()));
		assertEquals(null, new DoneBean().getLocalDateTimeFromHHmm("", LocalDateTime.now()));
		assertEquals(null, new DoneBean().getLocalDateTimeFromHHmm("  ", LocalDateTime.now()));
		assertEquals(ldt.withHour(0).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("0", LocalDateTime.now()));
		assertEquals(ldt.withHour(1).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("1", LocalDateTime.now()));
		assertEquals(ldt.withHour(5).withMinute(0), new DoneBean().getLocalDateTimeFromHHmm("5", LocalDateTime.now()));
	}
	
	@Test
	public void testSetDay() throws ParseException {
		String today = new SimpleDateFormat("dd.MM.yyyy").format(new Date());
		DateTimeFormatter sdf = DateTimeFormatter.ofPattern("dd.MM.yyyy HH:mm");
		DateTimeFormatter sd = DateTimeFormatter.ofPattern("dd.MM.yyyy");
		
		DoneBean bean = new DoneBean();
		bean.setDay(new Date());
		assertNull(bean.getTimeFrom());
		assertNull(bean.getTimeUntil());

		bean.setTimeFromString("08:00");
		LocalDateTime ts1 = bean.getTimeFrom();
		assertEquals(today.concat(" 08:00"), ts1.format(sdf));
		bean.setDay(new SimpleDateFormat("dd.MM.yyyy").parse("01.01.2001"));
		assertEquals("01.01.2001", bean.getTimeFrom().format(sd));
		assertNull(bean.getTimeUntil());

		bean.setTimeUntilString("10:00");
		LocalDateTime ts2 = bean.getTimeUntil();
		assertEquals(today.concat(" 10:00"), ts2.format(sdf));
		bean.setDay(new SimpleDateFormat("dd.MM.yyyy").parse("01.01.2001"));
		assertEquals("01.01.2001", sd.format(bean.getTimeFrom()));
		assertEquals("01.01.2001", sd.format(bean.getTimeUntil()));
	}
}
